BalderHub BLE
====================================

This is a BalderHub project for testing and interacting with devices that implement the Bluetooth Low Energy protocol. This module is for developing only and does not guarantee full compliance with the official specifications.

.. note::
   Please note, this package is still under development. If you would like to contribute, take a look into the
   `project <https://github.com/balder-dev/balderhub-ble/>`_.

This is a BalderHub package for the `Balder <https://docs.balder.dev/>`_ test framework. If you are new to Balder check
out the `official documentation <https://docs.balder.dev>`_ first.


.. toctree::
   :maxdepth: 2

   installation.rst
   topic_intro.rst
   scenarios.rst
   features.rst
   examples.rst
   utilities.rst
   contrib.rst
